"""
fiesta
======
A Python package for fine-tuning the ``intfloat/multilingual-e5-large-instruct``
embedding model with LoRA adapters for information-retrieval tasks.

Quick start
-----------
>>> from fiesta import MultilingualE5LargeInstructPipeline
>>> pipeline = MultilingualE5LargeInstructPipeline(kb_id="my-kb", lang="en")
>>> results = pipeline.train(raw_data)
>>> print(results.improvement())
"""

from __future__ import annotations

from fiesta.modelling import (
    LoraSettings,
    MultilingualE5LargeInstructModelling,
    TrainResult,
    TrainingSettings,
)
from fiesta.pipeline import (
    BasePipeline,
    MultilingualE5LargeInstructPipeline,
)
from fiesta.preprocessing import (
    MultilingualE5LargeInstructPreProcessing,
)

__version__: str = "0.1.0"
__author__: str = "fiesta contributors"

__all__: list[str] = [
    # Pipeline (high-level entry point)
    "MultilingualE5LargeInstructPipeline",
    "BasePipeline",
    # Modelling
    "MultilingualE5LargeInstructModelling",
    "LoraSettings",
    "TrainingSettings",
    "TrainResult",
    # Preprocessing
    "MultilingualE5LargeInstructPreProcessing",
    # Package metadata
    "__version__",
    "__author__",
]


